.. SPDX-FileCopyrightText: 2021 geisserml <geisserml@gmail.com>
.. SPDX-License-Identifier: CC-BY-4.0

PyPDFium2
=========

.. _PDFium documentation: https://developers.foxit.com/resources/pdf-sdk/c_api_reference_pdfium/group___f_p_d_f_i_u_m.html

Welcome to the API documentation for the support model of PyPDFium2.
For the low-level API, please also refer to the `PDFium documentation`_.

.. toctree::
   :maxdepth: 2
   :caption: Table of Contents
   
   support_api
   cli


Index
-----

* :ref:`genindex`
* :ref:`modindex`
